==> ejc-salary-api-3.0.0-20240920.092035-6-sources.jar: com/ejianc/business/salary/vo/JspayableAdjustVO.java <==
package com.ejianc.business.salary.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 应发公积金调整
 * 
 * @author generator
 * 
 */
public class JspayableAdjustVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long jspayableDetailId; // 所属明细id
    private Long sbcdOrgId; // 社保承担单位id
    private String sbcdOrgName; // 社保承担单位名称
    private String sbcdOrgCode; // 社保承担单位编码
    private String acSet; // 账套
    private String acSetCode; // 账套编码
    private BigDecimal personEndowmentMny; // 个人养老金额
    private BigDecimal personMedicalMny; // 个人医疗金额
    private BigDecimal personUnemploymentMny; // 个人失业金额
    private BigDecimal personHouseMny; // 个人公积金
    private BigDecimal companyEndowmentMny; // 公司养老金额
    private BigDecimal companyMedicalMny; // 公司医疗金额
    private BigDecimal companyUnemploymentMny; // 公司失业金额
    private BigDecimal companyBirthMny; // 公司生育金额
    private BigDecimal companyInjureMny; // 公司工伤金额
    private BigDecimal companyHouseMny; // 公司公积金
    private BigDecimal scale; // 占总额比例
    

    public Long getJspayableDetailId() {
        return jspayableDetailId;
    }

    public void setJspayableDetailId(Long jspayableDetailId) {
        this.jspayableDetailId = jspayableDetailId;
    }
    public Long getSbcdOrgId() {
        return sbcdOrgId;
    }

    public void setSbcdOrgId(Long sbcdOrgId) {
        this.sbcdOrgId = sbcdOrgId;
    }
    public String getSbcdOrgName() {
        return sbcdOrgName;
    }

    public void setSbcdOrgName(String sbcdOrgName) {
        this.sbcdOrgName = sbcdOrgName;
    }
    public String getSbcdOrgCode() {
        return sbcdOrgCode;
    }

    public void setSbcdOrgCode(String sbcdOrgCode) {
        this.sbcdOrgCode = sbcdOrgCode;
    }
    public String getAcSet() {
        return acSet;
    }

    public void setAcSet(String acSet) {
        this.acSet = acSet;
    }
    public String getAcSetCode() {
        return acSetCode;
    }

    public void setAcSetCode(String acSetCode) {
        this.acSetCode = acSetCode;
    }
    public BigDecimal getPersonEndowmentMny() {
        return personEndowmentMny;
    }

    public void setPersonEndowmentMny(BigDecimal personEndowmentMny) {
        this.personEndowmentMny = personEndowmentMny;
    }
    public BigDecimal getPersonMedicalMny() {
        return personMedicalMny;
    }

    public void setPersonMedicalMny(BigDecimal personMedicalMny) {
        this.personMedicalMny = personMedicalMny;
    }
    public BigDecimal getPersonUnemploymentMny() {
        return personUnemploymentMny;
    }

    public void setPersonUnemploymentMny(BigDecimal personUnemploymentMny) {
        this.personUnemploymentMny = personUnemploymentMny;
    }
    public BigDecimal getPersonHouseMny() {
        return personHouseMny;
    }

    public void setPersonHouseMny(BigDecimal personHouseMny) {
        this.personHouseMny = personHouseMny;
    }
    public BigDecimal getCompanyEndowmentMny() {
        return companyEndowmentMny;
    }

    public void setCompanyEndowmentMny(BigDecimal companyEndowmentMny) {
        this.companyEndowmentMny = companyEndowmentMny;
    }
    public BigDecimal getCompanyMedicalMny() {
        return companyMedicalMny;
    }

    public void setCompanyMedicalMny(BigDecimal companyMedicalMny) {
        this.companyMedicalMny = companyMedicalMny;
    }
    public BigDecimal getCompanyUnemploymentMny() {
        return companyUnemploymentMny;
    }

    public void setCompanyUnemploymentMny(BigDecimal companyUnemploymentMny) {
        this.companyUnemploymentMny = companyUnemploymentMny;
    }
    public BigDecimal getCompanyBirthMny() {
        return companyBirthMny;
    }

    public void setCompanyBirthMny(BigDecimal companyBirthMny) {
        this.companyBirthMny = companyBirthMny;
    }
    public BigDecimal getCompanyInjureMny() {
        return companyInjureMny;
    }

    public void setCompanyInjureMny(BigDecimal companyInjureMny) {
        this.companyInjureMny = companyInjureMny;
    }
    public BigDecimal getCompanyHouseMny() {
        return companyHouseMny;
    }

    public void setCompanyHouseMny(BigDecimal companyHouseMny) {
        this.companyHouseMny = companyHouseMny;
    }
    public BigDecimal getScale() {
        return scale;
    }

    public void setScale(BigDecimal scale) {
        this.scale = scale;
    }
    
}

==> ejc-salary-api-3.0.0-20241008.093320-14-sources.jar: com/ejianc/business/salary/vo/JspayableAdjustVO.java <==
package com.ejianc.business.salary.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 应发公积金调整
 * 
 * @author generator
 * 
 */
public class JspayableAdjustVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long jspayableDetailId; // 所属明细id
    private Long sbcdOrgId; // 社保承担单位id
    private String sbcdOrgName; // 社保承担单位名称
    private String sbcdOrgCode; // 社保承担单位编码
    private String acSet; // 账套
    private String acSetCode; // 账套编码
    private BigDecimal personEndowmentMny; // 个人养老金额
    private BigDecimal personMedicalMny; // 个人医疗金额
    private BigDecimal personUnemploymentMny; // 个人失业金额
    private BigDecimal personHouseMny; // 个人公积金
    private BigDecimal companyEndowmentMny; // 公司养老金额
    private BigDecimal companyMedicalMny; // 公司医疗金额
    private BigDecimal companyUnemploymentMny; // 公司失业金额
    private BigDecimal companyBirthMny; // 公司生育金额
    private BigDecimal companyInjureMny; // 公司工伤金额
    private BigDecimal companyHouseMny; // 公司公积金
    private BigDecimal scale; // 占总额比例
    private String idCard; // 证件号码
    private Date period; // 期间 应发工资计算的 月份
    private String isDefault; // 是否默认单位 1是,2-否
    

    public Long getJspayableDetailId() {
        return jspayableDetailId;
    }

    public void setJspayableDetailId(Long jspayableDetailId) {
        this.jspayableDetailId = jspayableDetailId;
    }
    public Long getSbcdOrgId() {
        return sbcdOrgId;
    }

    public void setSbcdOrgId(Long sbcdOrgId) {
        this.sbcdOrgId = sbcdOrgId;
    }
    public String getSbcdOrgName() {
        return sbcdOrgName;
    }

    public void setSbcdOrgName(String sbcdOrgName) {
        this.sbcdOrgName = sbcdOrgName;
    }
    public String getSbcdOrgCode() {
        return sbcdOrgCode;
    }

    public void setSbcdOrgCode(String sbcdOrgCode) {
        this.sbcdOrgCode = sbcdOrgCode;
    }
    public String getAcSet() {
        return acSet;
    }

    public void setAcSet(String acSet) {
        this.acSet = acSet;
    }
    public String getAcSetCode() {
        return acSetCode;
    }

    public void setAcSetCode(String acSetCode) {
        this.acSetCode = acSetCode;
    }
    public BigDecimal getPersonEndowmentMny() {
        return personEndowmentMny;
    }

    public void setPersonEndowmentMny(BigDecimal personEndowmentMny) {
        this.personEndowmentMny = personEndowmentMny;
    }
    public BigDecimal getPersonMedicalMny() {
        return personMedicalMny;
    }

    public void setPersonMedicalMny(BigDecimal personMedicalMny) {
        this.personMedicalMny = personMedicalMny;
    }
    public BigDecimal getPersonUnemploymentMny() {
        return personUnemploymentMny;
    }

    public void setPersonUnemploymentMny(BigDecimal personUnemploymentMny) {
        this.personUnemploymentMny = personUnemploymentMny;
    }
    public BigDecimal getPersonHouseMny() {
        return personHouseMny;
    }

    public void setPersonHouseMny(BigDecimal personHouseMny) {
        this.personHouseMny = personHouseMny;
    }
    public BigDecimal getCompanyEndowmentMny() {
        return companyEndowmentMny;
    }

    public void setCompanyEndowmentMny(BigDecimal companyEndowmentMny) {
        this.companyEndowmentMny = companyEndowmentMny;
    }
    public BigDecimal getCompanyMedicalMny() {
        return companyMedicalMny;
    }

    public void setCompanyMedicalMny(BigDecimal companyMedicalMny) {
        this.companyMedicalMny = companyMedicalMny;
    }
    public BigDecimal getCompanyUnemploymentMny() {
        return companyUnemploymentMny;
    }

    public void setCompanyUnemploymentMny(BigDecimal companyUnemploymentMny) {
        this.companyUnemploymentMny = companyUnemploymentMny;
    }
    public BigDecimal getCompanyBirthMny() {
        return companyBirthMny;
    }

    public void setCompanyBirthMny(BigDecimal companyBirthMny) {
        this.companyBirthMny = companyBirthMny;
    }
    public BigDecimal getCompanyInjureMny() {
        return companyInjureMny;
    }

    public void setCompanyInjureMny(BigDecimal companyInjureMny) {
        this.companyInjureMny = companyInjureMny;
    }
    public BigDecimal getCompanyHouseMny() {
        return companyHouseMny;
    }

    public void setCompanyHouseMny(BigDecimal companyHouseMny) {
        this.companyHouseMny = companyHouseMny;
    }
    public BigDecimal getScale() {
        return scale;
    }

    public void setScale(BigDecimal scale) {
        this.scale = scale;
    }

    public String getIsDefault() {
        return isDefault;
    }

    public void setIsDefault(String isDefault) {
        this.isDefault = isDefault;
    }

    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }

    public Date getPeriod() {
        return period;
    }

    public void setPeriod(Date period) {
        this.period = period;
    }
}
